@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "vscode-dark-plus-theme" "2.1.0"
+(define-package "vscode-dark-plus-theme" "20260219.422"
   "Default Visual Studio Code Dark+ theme."
   ()
   :url "https://github.com/ianpan870102/vscode-dark-plus-emacs-theme"
-  :commit "37f16729ee196dbfc533b02adea3d2129bdd8585"
-  :revdesc "37f16729ee19")
+  :commit "0f6b41f9362590b56cc1d1fc4d2220fed72ebc8b"
+  :revdesc "0f6b41f93625")
